import typing

import typing_extensions

_list = list

@typing.type_check_only
class ApplicationInfo(typing_extensions.TypedDict, total=False):
    emails: _list[str]
    instruction: str
    uris: _list[str]

@typing.type_check_only
class BatchDeleteJobsRequest(typing_extensions.TypedDict, total=False):
    filter: str

AlternativeBucketRange = typing_extensions.TypedDict(
    "AlternativeBucketRange",
    {
        "from": float,
        "to": float,
    },
    total=False,
)

@typing.type_check_only
class BucketRange(AlternativeBucketRange): ...

@typing.type_check_only
class BucketizedCount(typing_extensions.TypedDict, total=False):
    count: int
    range: BucketRange

@typing.type_check_only
class ClientEvent(typing_extensions.TypedDict, total=False):
    createTime: str
    eventId: str
    extraInfo: dict[str, typing.Any]
    jobEvent: JobEvent
    parentEventId: str
    requestId: str

@typing.type_check_only
class CommuteFilter(typing_extensions.TypedDict, total=False):
    allowImpreciseAddresses: bool
    commuteMethod: typing_extensions.Literal[
        "COMMUTE_METHOD_UNSPECIFIED", "DRIVING", "TRANSIT", "WALKING", "CYCLING"
    ]
    departureTime: TimeOfDay
    roadTraffic: typing_extensions.Literal[
        "ROAD_TRAFFIC_UNSPECIFIED", "TRAFFIC_FREE", "BUSY_HOUR"
    ]
    startCoordinates: LatLng
    travelDuration: str

@typing.type_check_only
class CommuteInfo(typing_extensions.TypedDict, total=False):
    jobLocation: Location
    travelDuration: str

@typing.type_check_only
class Company(typing_extensions.TypedDict, total=False):
    careerSiteUri: str
    derivedInfo: CompanyDerivedInfo
    displayName: str
    eeoText: str
    externalId: str
    headquartersAddress: str
    hiringAgency: bool
    imageUri: str
    keywordSearchableJobCustomAttributes: _list[str]
    name: str
    size: typing_extensions.Literal[
        "COMPANY_SIZE_UNSPECIFIED",
        "MINI",
        "SMALL",
        "SMEDIUM",
        "MEDIUM",
        "BIG",
        "BIGGER",
        "GIANT",
    ]
    suspended: bool
    websiteUri: str

@typing.type_check_only
class CompanyDerivedInfo(typing_extensions.TypedDict, total=False):
    headquartersLocation: Location

@typing.type_check_only
class CompensationEntry(typing_extensions.TypedDict, total=False):
    amount: Money
    description: str
    expectedUnitsPerYear: float
    range: CompensationRange
    type: typing_extensions.Literal[
        "COMPENSATION_TYPE_UNSPECIFIED",
        "BASE",
        "BONUS",
        "SIGNING_BONUS",
        "EQUITY",
        "PROFIT_SHARING",
        "COMMISSIONS",
        "TIPS",
        "OTHER_COMPENSATION_TYPE",
    ]
    unit: typing_extensions.Literal[
        "COMPENSATION_UNIT_UNSPECIFIED",
        "HOURLY",
        "DAILY",
        "WEEKLY",
        "MONTHLY",
        "YEARLY",
        "ONE_TIME",
        "OTHER_COMPENSATION_UNIT",
    ]

@typing.type_check_only
class CompensationFilter(typing_extensions.TypedDict, total=False):
    includeJobsWithUnspecifiedCompensationRange: bool
    range: CompensationRange
    type: typing_extensions.Literal[
        "FILTER_TYPE_UNSPECIFIED",
        "UNIT_ONLY",
        "UNIT_AND_AMOUNT",
        "ANNUALIZED_BASE_AMOUNT",
        "ANNUALIZED_TOTAL_AMOUNT",
    ]
    units: _list[str]

@typing.type_check_only
class CompensationHistogramRequest(typing_extensions.TypedDict, total=False):
    bucketingOption: NumericBucketingOption
    type: typing_extensions.Literal[
        "COMPENSATION_HISTOGRAM_REQUEST_TYPE_UNSPECIFIED",
        "BASE",
        "ANNUALIZED_BASE",
        "ANNUALIZED_TOTAL",
    ]

@typing.type_check_only
class CompensationHistogramResult(typing_extensions.TypedDict, total=False):
    result: NumericBucketingResult
    type: typing_extensions.Literal[
        "COMPENSATION_HISTOGRAM_REQUEST_TYPE_UNSPECIFIED",
        "BASE",
        "ANNUALIZED_BASE",
        "ANNUALIZED_TOTAL",
    ]

@typing.type_check_only
class CompensationInfo(typing_extensions.TypedDict, total=False):
    annualizedBaseCompensationRange: CompensationRange
    annualizedTotalCompensationRange: CompensationRange
    entries: _list[CompensationEntry]

@typing.type_check_only
class CompensationRange(typing_extensions.TypedDict, total=False):
    maxCompensation: Money
    minCompensation: Money

@typing.type_check_only
class CompleteQueryResponse(typing_extensions.TypedDict, total=False):
    completionResults: _list[CompletionResult]
    metadata: ResponseMetadata

@typing.type_check_only
class CompletionResult(typing_extensions.TypedDict, total=False):
    imageUri: str
    suggestion: str
    type: typing_extensions.Literal[
        "COMPLETION_TYPE_UNSPECIFIED", "JOB_TITLE", "COMPANY_NAME", "COMBINED"
    ]

@typing.type_check_only
class CreateClientEventRequest(typing_extensions.TypedDict, total=False):
    clientEvent: ClientEvent

@typing.type_check_only
class CreateCompanyRequest(typing_extensions.TypedDict, total=False):
    company: Company

@typing.type_check_only
class CreateJobRequest(typing_extensions.TypedDict, total=False):
    job: Job

@typing.type_check_only
class CustomAttribute(typing_extensions.TypedDict, total=False):
    filterable: bool
    longValues: _list[str]
    stringValues: _list[str]

@typing.type_check_only
class CustomAttributeHistogramRequest(typing_extensions.TypedDict, total=False):
    key: str
    longValueHistogramBucketingOption: NumericBucketingOption
    stringValueHistogram: bool

@typing.type_check_only
class CustomAttributeHistogramResult(typing_extensions.TypedDict, total=False):
    key: str
    longValueHistogramResult: NumericBucketingResult
    stringValueHistogramResult: dict[str, typing.Any]

@typing.type_check_only
class CustomRankingInfo(typing_extensions.TypedDict, total=False):
    importanceLevel: typing_extensions.Literal[
        "IMPORTANCE_LEVEL_UNSPECIFIED",
        "NONE",
        "LOW",
        "MILD",
        "MEDIUM",
        "HIGH",
        "EXTREME",
    ]
    rankingExpression: str

@typing.type_check_only
class DeviceInfo(typing_extensions.TypedDict, total=False):
    deviceType: typing_extensions.Literal[
        "DEVICE_TYPE_UNSPECIFIED", "WEB", "MOBILE_WEB", "ANDROID", "IOS", "BOT", "OTHER"
    ]
    id: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class HistogramFacets(typing_extensions.TypedDict, total=False):
    compensationHistogramFacets: _list[CompensationHistogramRequest]
    customAttributeHistogramFacets: _list[CustomAttributeHistogramRequest]
    simpleHistogramFacets: _list[str]

@typing.type_check_only
class HistogramQuery(typing_extensions.TypedDict, total=False):
    histogramQuery: str

@typing.type_check_only
class HistogramQueryResult(typing_extensions.TypedDict, total=False):
    histogram: dict[str, typing.Any]
    histogramQuery: str

@typing.type_check_only
class HistogramResult(typing_extensions.TypedDict, total=False):
    searchType: typing_extensions.Literal[
        "SEARCH_TYPE_UNSPECIFIED",
        "COMPANY_ID",
        "EMPLOYMENT_TYPE",
        "COMPANY_SIZE",
        "DATE_PUBLISHED",
        "EDUCATION_LEVEL",
        "EXPERIENCE_LEVEL",
        "ADMIN_1",
        "COUNTRY",
        "CITY",
        "LOCALE",
        "LANGUAGE",
        "CATEGORY",
        "CITY_COORDINATE",
        "ADMIN_1_COUNTRY",
        "COMPANY_DISPLAY_NAME",
        "BASE_COMPENSATION_UNIT",
    ]
    values: dict[str, typing.Any]

@typing.type_check_only
class HistogramResults(typing_extensions.TypedDict, total=False):
    compensationHistogramResults: _list[CompensationHistogramResult]
    customAttributeHistogramResults: _list[CustomAttributeHistogramResult]
    simpleHistogramResults: _list[HistogramResult]

@typing.type_check_only
class Job(typing_extensions.TypedDict, total=False):
    addresses: _list[str]
    applicationInfo: ApplicationInfo
    companyDisplayName: str
    companyName: str
    compensationInfo: CompensationInfo
    customAttributes: dict[str, typing.Any]
    degreeTypes: _list[str]
    department: str
    derivedInfo: JobDerivedInfo
    description: str
    employmentTypes: _list[str]
    incentives: str
    jobBenefits: _list[str]
    jobEndTime: str
    jobLevel: typing_extensions.Literal[
        "JOB_LEVEL_UNSPECIFIED",
        "ENTRY_LEVEL",
        "EXPERIENCED",
        "MANAGER",
        "DIRECTOR",
        "EXECUTIVE",
    ]
    jobStartTime: str
    languageCode: str
    name: str
    postingCreateTime: str
    postingExpireTime: str
    postingPublishTime: str
    postingRegion: typing_extensions.Literal[
        "POSTING_REGION_UNSPECIFIED", "ADMINISTRATIVE_AREA", "NATION", "TELECOMMUTE"
    ]
    postingUpdateTime: str
    processingOptions: ProcessingOptions
    promotionValue: int
    qualifications: str
    requisitionId: str
    responsibilities: str
    title: str
    visibility: typing_extensions.Literal[
        "VISIBILITY_UNSPECIFIED",
        "ACCOUNT_ONLY",
        "SHARED_WITH_GOOGLE",
        "SHARED_WITH_PUBLIC",
    ]

@typing.type_check_only
class JobDerivedInfo(typing_extensions.TypedDict, total=False):
    jobCategories: _list[str]
    locations: _list[Location]

@typing.type_check_only
class JobEvent(typing_extensions.TypedDict, total=False):
    jobs: _list[str]
    type: typing_extensions.Literal[
        "JOB_EVENT_TYPE_UNSPECIFIED",
        "IMPRESSION",
        "VIEW",
        "VIEW_REDIRECT",
        "APPLICATION_START",
        "APPLICATION_FINISH",
        "APPLICATION_QUICK_SUBMISSION",
        "APPLICATION_REDIRECT",
        "APPLICATION_START_FROM_SEARCH",
        "APPLICATION_REDIRECT_FROM_SEARCH",
        "APPLICATION_COMPANY_SUBMIT",
        "BOOKMARK",
        "NOTIFICATION",
        "HIRED",
        "SENT_CV",
        "INTERVIEW_GRANTED",
        "NOT_INTERESTED",
    ]

@typing.type_check_only
class JobQuery(typing_extensions.TypedDict, total=False):
    commuteFilter: CommuteFilter
    companyDisplayNames: _list[str]
    companyNames: _list[str]
    compensationFilter: CompensationFilter
    customAttributeFilter: str
    disableSpellCheck: bool
    employmentTypes: _list[str]
    excludedJobs: _list[str]
    jobCategories: _list[str]
    languageCodes: _list[str]
    locationFilters: _list[LocationFilter]
    publishTimeRange: TimestampRange
    query: str
    queryLanguageCode: str

@typing.type_check_only
class LatLng(typing_extensions.TypedDict, total=False):
    latitude: float
    longitude: float

@typing.type_check_only
class ListCompaniesResponse(typing_extensions.TypedDict, total=False):
    companies: _list[Company]
    metadata: ResponseMetadata
    nextPageToken: str

@typing.type_check_only
class ListJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[Job]
    metadata: ResponseMetadata
    nextPageToken: str

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    latLng: LatLng
    locationType: typing_extensions.Literal[
        "LOCATION_TYPE_UNSPECIFIED",
        "COUNTRY",
        "ADMINISTRATIVE_AREA",
        "SUB_ADMINISTRATIVE_AREA",
        "LOCALITY",
        "POSTAL_CODE",
        "SUB_LOCALITY",
        "SUB_LOCALITY_1",
        "SUB_LOCALITY_2",
        "NEIGHBORHOOD",
        "STREET_ADDRESS",
    ]
    postalAddress: PostalAddress
    radiusInMiles: float

@typing.type_check_only
class LocationFilter(typing_extensions.TypedDict, total=False):
    address: str
    distanceInMiles: float
    latLng: LatLng
    regionCode: str
    telecommutePreference: typing_extensions.Literal[
        "TELECOMMUTE_PREFERENCE_UNSPECIFIED",
        "TELECOMMUTE_EXCLUDED",
        "TELECOMMUTE_ALLOWED",
        "TELECOMMUTE_JOBS_EXCLUDED",
    ]

@typing.type_check_only
class MatchingJob(typing_extensions.TypedDict, total=False):
    commuteInfo: CommuteInfo
    job: Job
    jobSummary: str
    jobTitleSnippet: str
    searchTextSnippet: str

@typing.type_check_only
class MendelDebugInput(typing_extensions.TypedDict, total=False):
    namespacedDebugInput: dict[str, typing.Any]

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class NamespacedDebugInput(typing_extensions.TypedDict, total=False):
    absolutelyForcedExpNames: _list[str]
    absolutelyForcedExpTags: _list[str]
    absolutelyForcedExps: _list[int]
    conditionallyForcedExpNames: _list[str]
    conditionallyForcedExpTags: _list[str]
    conditionallyForcedExps: _list[int]
    disableAutomaticEnrollmentSelection: bool
    disableExpNames: _list[str]
    disableExpTags: _list[str]
    disableExps: _list[int]
    disableManualEnrollmentSelection: bool
    disableOrganicSelection: bool
    forcedFlags: dict[str, typing.Any]
    forcedRollouts: dict[str, typing.Any]
    testingMode: typing_extensions.Literal[
        "TESTING_MODE_UNSPECIFIED", "TESTING_MODE_ALL_OFF", "TESTING_MODE_ALL_ON"
    ]

@typing.type_check_only
class NumericBucketingOption(typing_extensions.TypedDict, total=False):
    bucketBounds: _list[float]
    requiresMinMax: bool

@typing.type_check_only
class NumericBucketingResult(typing_extensions.TypedDict, total=False):
    counts: _list[BucketizedCount]
    maxValue: float
    minValue: float

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class PostalAddress(typing_extensions.TypedDict, total=False):
    addressLines: _list[str]
    administrativeArea: str
    languageCode: str
    locality: str
    organization: str
    postalCode: str
    recipients: _list[str]
    regionCode: str
    revision: int
    sortingCode: str
    sublocality: str

@typing.type_check_only
class ProcessingOptions(typing_extensions.TypedDict, total=False):
    disableStreetAddressResolution: bool
    htmlSanitization: typing_extensions.Literal[
        "HTML_SANITIZATION_UNSPECIFIED",
        "HTML_SANITIZATION_DISABLED",
        "SIMPLE_FORMATTING_ONLY",
    ]

@typing.type_check_only
class RequestMetadata(typing_extensions.TypedDict, total=False):
    deviceInfo: DeviceInfo
    domain: str
    sessionId: str
    userId: str

@typing.type_check_only
class ResponseMetadata(typing_extensions.TypedDict, total=False):
    requestId: str

@typing.type_check_only
class SearchJobsRequest(typing_extensions.TypedDict, total=False):
    customRankingInfo: CustomRankingInfo
    disableKeywordMatch: bool
    diversificationLevel: typing_extensions.Literal[
        "DIVERSIFICATION_LEVEL_UNSPECIFIED", "DISABLED", "SIMPLE"
    ]
    enableBroadening: bool
    histogramFacets: HistogramFacets
    histogramQueries: _list[HistogramQuery]
    jobQuery: JobQuery
    jobView: typing_extensions.Literal[
        "JOB_VIEW_UNSPECIFIED",
        "JOB_VIEW_ID_ONLY",
        "JOB_VIEW_MINIMAL",
        "JOB_VIEW_SMALL",
        "JOB_VIEW_FULL",
    ]
    offset: int
    orderBy: str
    pageSize: int
    pageToken: str
    requestMetadata: RequestMetadata
    requirePreciseResultSize: bool
    searchMode: typing_extensions.Literal[
        "SEARCH_MODE_UNSPECIFIED", "JOB_SEARCH", "FEATURED_JOB_SEARCH"
    ]

@typing.type_check_only
class SearchJobsResponse(typing_extensions.TypedDict, total=False):
    broadenedQueryJobsCount: int
    estimatedTotalSize: int
    histogramQueryResults: _list[HistogramQueryResult]
    histogramResults: HistogramResults
    locationFilters: _list[Location]
    matchingJobs: _list[MatchingJob]
    metadata: ResponseMetadata
    nextPageToken: str
    spellCorrection: SpellingCorrection
    totalSize: int

@typing.type_check_only
class SpellingCorrection(typing_extensions.TypedDict, total=False):
    corrected: bool
    correctedText: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TimeOfDay(typing_extensions.TypedDict, total=False):
    hours: int
    minutes: int
    nanos: int
    seconds: int

@typing.type_check_only
class TimestampRange(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class UpdateCompanyRequest(typing_extensions.TypedDict, total=False):
    company: Company
    updateMask: str

@typing.type_check_only
class UpdateJobRequest(typing_extensions.TypedDict, total=False):
    job: Job
    updateMask: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FirebaseappcheckResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class JwksResource(googleapiclient.discovery.Resource):
        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleFirebaseAppcheckV1betaPublicJwkSetHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AppsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AppAttestConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetAppAttestConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaAppAttestConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaAppAttestConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaAppAttestConfigHttpRequest: ...

            @typing.type_check_only
            class DebugTokensResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleFirebaseAppcheckV1betaDebugToken = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaDebugTokenHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaDebugTokenHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaListDebugTokensResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleFirebaseAppcheckV1betaListDebugTokensResponseHttpRequest,
                    previous_response: GoogleFirebaseAppcheckV1betaListDebugTokensResponse,
                ) -> GoogleFirebaseAppcheckV1betaListDebugTokensResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaDebugToken = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaDebugTokenHttpRequest: ...

            @typing.type_check_only
            class DeviceCheckConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetDeviceCheckConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaDeviceCheckConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaDeviceCheckConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaDeviceCheckConfigHttpRequest: ...

            @typing.type_check_only
            class PlayIntegrityConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetPlayIntegrityConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaPlayIntegrityConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaPlayIntegrityConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaPlayIntegrityConfigHttpRequest: ...

            @typing.type_check_only
            class RecaptchaConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetRecaptchaConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaRecaptchaConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaRecaptchaConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaRecaptchaConfigHttpRequest: ...

            @typing.type_check_only
            class RecaptchaEnterpriseConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetRecaptchaEnterpriseConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigHttpRequest: ...

            @typing.type_check_only
            class RecaptchaV3ConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetRecaptchaV3ConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaRecaptchaV3ConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaRecaptchaV3Config = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaRecaptchaV3ConfigHttpRequest: ...

            @typing.type_check_only
            class SafetyNetConfigResource(googleapiclient.discovery.Resource):
                def batchGet(
                    self,
                    *,
                    parent: str,
                    names: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaBatchGetSafetyNetConfigsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaSafetyNetConfigHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleFirebaseAppcheckV1betaSafetyNetConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseAppcheckV1betaSafetyNetConfigHttpRequest: ...

            def exchangeAppAttestAssertion(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeAppAttestAttestation(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationResponseHttpRequest: ...
            def exchangeCustomToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeDebugToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeDebugTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeDeviceCheckToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeDeviceCheckTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangePlayIntegrityToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangePlayIntegrityTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeRecaptchaEnterpriseToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeRecaptchaEnterpriseTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeRecaptchaToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeRecaptchaTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeRecaptchaV3Token(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeRecaptchaV3TokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def exchangeSafetyNetToken(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaExchangeSafetyNetTokenRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest: ...
            def generateAppAttestChallenge(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeResponseHttpRequest: ...
            def generatePlayIntegrityChallenge(
                self,
                *,
                app: str,
                body: GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeResponseHttpRequest: ...
            def appAttestConfig(self) -> AppAttestConfigResource: ...
            def debugTokens(self) -> DebugTokensResource: ...
            def deviceCheckConfig(self) -> DeviceCheckConfigResource: ...
            def playIntegrityConfig(self) -> PlayIntegrityConfigResource: ...
            def recaptchaConfig(self) -> RecaptchaConfigResource: ...
            def recaptchaEnterpriseConfig(
                self,
            ) -> RecaptchaEnterpriseConfigResource: ...
            def recaptchaV3Config(self) -> RecaptchaV3ConfigResource: ...
            def safetyNetConfig(self) -> SafetyNetConfigResource: ...

        @typing.type_check_only
        class ServicesResource(googleapiclient.discovery.Resource):
            def batchUpdate(
                self,
                *,
                parent: str,
                body: GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaBatchUpdateServicesResponseHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaServiceHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaListServicesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleFirebaseAppcheckV1betaListServicesResponseHttpRequest,
                previous_response: GoogleFirebaseAppcheckV1betaListServicesResponse,
            ) -> GoogleFirebaseAppcheckV1betaListServicesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleFirebaseAppcheckV1betaService = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleFirebaseAppcheckV1betaServiceHttpRequest: ...

        def apps(self) -> AppsResource: ...
        def services(self) -> ServicesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def jwks(self) -> JwksResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaAppAttestConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaAppAttestConfig: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaAppCheckTokenHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaAppCheckToken: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetAppAttestConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetAppAttestConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetDeviceCheckConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetDeviceCheckConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetPlayIntegrityConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetPlayIntegrityConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetRecaptchaConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetRecaptchaConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetRecaptchaEnterpriseConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetRecaptchaEnterpriseConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetRecaptchaV3ConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetRecaptchaV3ConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetSafetyNetConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchGetSafetyNetConfigsResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchUpdateServicesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaBatchUpdateServicesResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaDebugTokenHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaDebugToken: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaDeviceCheckConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaDeviceCheckConfig: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaListDebugTokensResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaListDebugTokensResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaListServicesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaListServicesResponse: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaPlayIntegrityConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaPlayIntegrityConfig: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaPublicJwkSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaPublicJwkSet: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaRecaptchaConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaRecaptchaConfig: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaRecaptchaV3ConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaRecaptchaV3Config: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaSafetyNetConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaSafetyNetConfig: ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaServiceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseAppcheckV1betaService: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AllowedIpRange(typing_extensions.TypedDict, total=False):
    description: str
    value: str

@typing.type_check_only
class CheckUpgradeResponse(typing_extensions.TypedDict, total=False):
    buildLogUri: str
    containsPypiModulesConflict: typing_extensions.Literal[
        "CONFLICT_RESULT_UNSPECIFIED", "CONFLICT", "NO_CONFLICT"
    ]
    imageVersion: str
    pypiConflictBuildLogExtract: str
    pypiDependencies: dict[str, typing.Any]

@typing.type_check_only
class CidrBlock(typing_extensions.TypedDict, total=False):
    cidrBlock: str
    displayName: str

@typing.type_check_only
class DatabaseConfig(typing_extensions.TypedDict, total=False):
    machineType: str

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EncryptionConfig(typing_extensions.TypedDict, total=False):
    kmsKeyName: str

@typing.type_check_only
class Environment(typing_extensions.TypedDict, total=False):
    config: EnvironmentConfig
    createTime: str
    labels: dict[str, typing.Any]
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "RUNNING", "UPDATING", "DELETING", "ERROR"
    ]
    updateTime: str
    uuid: str

@typing.type_check_only
class EnvironmentConfig(typing_extensions.TypedDict, total=False):
    airflowUri: str
    dagGcsPrefix: str
    databaseConfig: DatabaseConfig
    encryptionConfig: EncryptionConfig
    environmentSize: typing_extensions.Literal[
        "ENVIRONMENT_SIZE_UNSPECIFIED",
        "ENVIRONMENT_SIZE_SMALL",
        "ENVIRONMENT_SIZE_MEDIUM",
        "ENVIRONMENT_SIZE_LARGE",
    ]
    gkeCluster: str
    maintenanceWindow: MaintenanceWindow
    masterAuthorizedNetworksConfig: MasterAuthorizedNetworksConfig
    nodeConfig: NodeConfig
    nodeCount: int
    privateEnvironmentConfig: PrivateEnvironmentConfig
    softwareConfig: SoftwareConfig
    webServerConfig: WebServerConfig
    webServerNetworkAccessControl: WebServerNetworkAccessControl
    workloadsConfig: WorkloadsConfig

@typing.type_check_only
class IPAllocationPolicy(typing_extensions.TypedDict, total=False):
    clusterIpv4CidrBlock: str
    clusterSecondaryRangeName: str
    servicesIpv4CidrBlock: str
    servicesSecondaryRangeName: str
    useIpAliases: bool

@typing.type_check_only
class ImageVersion(typing_extensions.TypedDict, total=False):
    creationDisabled: bool
    imageVersionId: str
    isDefault: bool
    releaseDate: Date
    supportedPythonVersions: _list[str]
    upgradeDisabled: bool

@typing.type_check_only
class ListEnvironmentsResponse(typing_extensions.TypedDict, total=False):
    environments: _list[Environment]
    nextPageToken: str

@typing.type_check_only
class ListImageVersionsResponse(typing_extensions.TypedDict, total=False):
    imageVersions: _list[ImageVersion]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class LoadSnapshotResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class MaintenanceWindow(typing_extensions.TypedDict, total=False):
    endTime: str
    recurrence: str
    startTime: str

@typing.type_check_only
class MasterAuthorizedNetworksConfig(typing_extensions.TypedDict, total=False):
    cidrBlocks: _list[CidrBlock]
    enabled: bool

@typing.type_check_only
class NodeConfig(typing_extensions.TypedDict, total=False):
    diskSizeGb: int
    enableIpMasqAgent: bool
    ipAllocationPolicy: IPAllocationPolicy
    location: str
    machineType: str
    network: str
    oauthScopes: _list[str]
    serviceAccount: str
    subnetwork: str
    tags: _list[str]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    createTime: str
    endTime: str
    operationType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "CREATE",
        "DELETE",
        "UPDATE",
        "CHECK",
        "SAVE_SNAPSHOT",
        "LOAD_SNAPSHOT",
    ]
    resource: str
    resourceUuid: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "SUCCESSFUL", "FAILED"
    ]

@typing.type_check_only
class PrivateClusterConfig(typing_extensions.TypedDict, total=False):
    enablePrivateEndpoint: bool
    masterIpv4CidrBlock: str
    masterIpv4ReservedRange: str

@typing.type_check_only
class PrivateEnvironmentConfig(typing_extensions.TypedDict, total=False):
    cloudComposerConnectionSubnetwork: str
    cloudComposerNetworkIpv4CidrBlock: str
    cloudComposerNetworkIpv4ReservedRange: str
    cloudSqlIpv4CidrBlock: str
    enablePrivateEnvironment: bool
    enablePrivatelyUsedPublicIps: bool
    privateClusterConfig: PrivateClusterConfig
    webServerIpv4CidrBlock: str
    webServerIpv4ReservedRange: str

@typing.type_check_only
class SaveSnapshotResponse(typing_extensions.TypedDict, total=False):
    snapshotPath: str

@typing.type_check_only
class SchedulerResource(typing_extensions.TypedDict, total=False):
    count: int
    cpu: float
    memoryGb: float
    storageGb: float

@typing.type_check_only
class SoftwareConfig(typing_extensions.TypedDict, total=False):
    airflowConfigOverrides: dict[str, typing.Any]
    envVariables: dict[str, typing.Any]
    imageVersion: str
    pypiPackages: dict[str, typing.Any]
    pythonVersion: str
    schedulerCount: int

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class WebServerConfig(typing_extensions.TypedDict, total=False):
    machineType: str

@typing.type_check_only
class WebServerNetworkAccessControl(typing_extensions.TypedDict, total=False):
    allowedIpRanges: _list[AllowedIpRange]

@typing.type_check_only
class WebServerResource(typing_extensions.TypedDict, total=False):
    cpu: float
    memoryGb: float
    storageGb: float

@typing.type_check_only
class WorkerResource(typing_extensions.TypedDict, total=False):
    cpu: float
    maxCount: int
    memoryGb: float
    minCount: int
    storageGb: float

@typing.type_check_only
class WorkloadsConfig(typing_extensions.TypedDict, total=False):
    scheduler: SchedulerResource
    webServer: WebServerResource
    worker: WorkerResource



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class PolyServiceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AssetsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> AssetHttpRequest: ...
        def list(
            self,
            *,
            category: str = ...,
            curated: bool = ...,
            format: str = ...,
            keywords: str = ...,
            maxComplexity: typing_extensions.Literal[
                "COMPLEXITY_UNSPECIFIED", "COMPLEX", "MEDIUM", "SIMPLE"
            ] = ...,
            orderBy: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListAssetsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListAssetsResponseHttpRequest,
            previous_response: ListAssetsResponse,
        ) -> ListAssetsResponseHttpRequest | None: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AssetsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                name: str,
                format: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                visibility: typing_extensions.Literal[
                    "VISIBILITY_UNSPECIFIED", "PUBLISHED", "PRIVATE"
                ] = ...,
                **kwargs: typing.Any
            ) -> ListUserAssetsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListUserAssetsResponseHttpRequest,
                previous_response: ListUserAssetsResponse,
            ) -> ListUserAssetsResponseHttpRequest | None: ...

        @typing.type_check_only
        class LikedassetsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                name: str,
                format: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLikedAssetsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLikedAssetsResponseHttpRequest,
                previous_response: ListLikedAssetsResponse,
            ) -> ListLikedAssetsResponseHttpRequest | None: ...

        def assets(self) -> AssetsResource: ...
        def likedassets(self) -> LikedassetsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def assets(self) -> AssetsResource: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class AssetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Asset: ...

@typing.type_check_only
class ListAssetsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAssetsResponse: ...

@typing.type_check_only
class ListLikedAssetsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLikedAssetsResponse: ...

@typing.type_check_only
class ListUserAssetsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUserAssetsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DirectoryResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AspsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, userKey: str, codeId: int, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, userKey: str, codeId: int, **kwargs: typing.Any
        ) -> AspHttpRequest: ...
        def list(self, *, userKey: str, **kwargs: typing.Any) -> AspsHttpRequest: ...

    @typing.type_check_only
    class ChannelsResource(googleapiclient.discovery.Resource):
        def stop(
            self, *, body: Channel = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ChromeosdevicesResource(googleapiclient.discovery.Resource):
        def action(
            self,
            *,
            customerId: str,
            resourceId: str,
            body: ChromeOsDeviceAction = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            customerId: str,
            deviceId: str,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> ChromeOsDeviceHttpRequest: ...
        def list(
            self,
            *,
            customerId: str,
            includeChildOrgunits: bool = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "annotatedLocation",
                "annotatedUser",
                "lastSync",
                "notes",
                "serialNumber",
                "status",
            ] = ...,
            orgUnitPath: str = ...,
            pageToken: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            query: str = ...,
            sortOrder: typing_extensions.Literal["ASCENDING", "DESCENDING"] = ...,
            **kwargs: typing.Any
        ) -> ChromeOsDevicesHttpRequest: ...
        def list_next(
            self,
            previous_request: ChromeOsDevicesHttpRequest,
            previous_response: ChromeOsDevices,
        ) -> ChromeOsDevicesHttpRequest | None: ...
        def moveDevicesToOu(
            self,
            *,
            customerId: str,
            orgUnitPath: str,
            body: ChromeOsMoveDevicesToOu = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def patch(
            self,
            *,
            customerId: str,
            deviceId: str,
            body: ChromeOsDevice = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> ChromeOsDeviceHttpRequest: ...
        def update(
            self,
            *,
            customerId: str,
            deviceId: str,
            body: ChromeOsDevice = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> ChromeOsDeviceHttpRequest: ...

    @typing.type_check_only
    class CustomerResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DevicesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ChromeosResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class CommandsResource(googleapiclient.discovery.Resource):
                    def get(
                        self,
                        *,
                        customerId: str,
                        deviceId: str,
                        commandId: str,
                        **kwargs: typing.Any
                    ) -> DirectoryChromeosdevicesCommandHttpRequest: ...

                def issueCommand(
                    self,
                    *,
                    customerId: str,
                    deviceId: str,
                    body: DirectoryChromeosdevicesIssueCommandRequest = ...,
                    **kwargs: typing.Any
                ) -> DirectoryChromeosdevicesIssueCommandResponseHttpRequest: ...
                def commands(self) -> CommandsResource: ...

            def chromeos(self) -> ChromeosResource: ...

        def devices(self) -> DevicesResource: ...

    @typing.type_check_only
    class CustomersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ChromeResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class PrintServersResource(googleapiclient.discovery.Resource):
                def batchCreatePrintServers(
                    self,
                    *,
                    parent: str,
                    body: BatchCreatePrintServersRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchCreatePrintServersResponseHttpRequest: ...
                def batchDeletePrintServers(
                    self,
                    *,
                    parent: str,
                    body: BatchDeletePrintServersRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchDeletePrintServersResponseHttpRequest: ...
                def create(
                    self, *, parent: str, body: PrintServer = ..., **kwargs: typing.Any
                ) -> PrintServerHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> PrintServerHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    orgUnitId: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListPrintServersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListPrintServersResponseHttpRequest,
                    previous_response: ListPrintServersResponse,
                ) -> ListPrintServersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: PrintServer = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> PrintServerHttpRequest: ...

            @typing.type_check_only
            class PrintersResource(googleapiclient.discovery.Resource):
                def batchCreatePrinters(
                    self,
                    *,
                    parent: str,
                    body: BatchCreatePrintersRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchCreatePrintersResponseHttpRequest: ...
                def batchDeletePrinters(
                    self,
                    *,
                    parent: str,
                    body: BatchDeletePrintersRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchDeletePrintersResponseHttpRequest: ...
                def create(
                    self, *, parent: str, body: Printer = ..., **kwargs: typing.Any
                ) -> PrinterHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> PrinterHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    orgUnitId: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListPrintersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListPrintersResponseHttpRequest,
                    previous_response: ListPrintersResponse,
                ) -> ListPrintersResponseHttpRequest | None: ...
                def listPrinterModels(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListPrinterModelsResponseHttpRequest: ...
                def listPrinterModels_next(
                    self,
                    previous_request: ListPrinterModelsResponseHttpRequest,
                    previous_response: ListPrinterModelsResponse,
                ) -> ListPrinterModelsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Printer = ...,
                    clearMask: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> PrinterHttpRequest: ...

            def printServers(self) -> PrintServersResource: ...
            def printers(self) -> PrintersResource: ...

        def get(
            self, *, customerKey: str, **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...
        def patch(
            self, *, customerKey: str, body: Customer = ..., **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...
        def update(
            self, *, customerKey: str, body: Customer = ..., **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...
        def chrome(self) -> ChromeResource: ...

    @typing.type_check_only
    class DomainAliasesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, customer: str, domainAliasName: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customer: str, domainAliasName: str, **kwargs: typing.Any
        ) -> DomainAliasHttpRequest: ...
        def insert(
            self, *, customer: str, body: DomainAlias = ..., **kwargs: typing.Any
        ) -> DomainAliasHttpRequest: ...
        def list(
            self, *, customer: str, parentDomainName: str = ..., **kwargs: typing.Any
        ) -> DomainAliasesHttpRequest: ...

    @typing.type_check_only
    class DomainsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, customer: str, domainName: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customer: str, domainName: str, **kwargs: typing.Any
        ) -> DomainsHttpRequest: ...
        def insert(
            self, *, customer: str, body: Domains = ..., **kwargs: typing.Any
        ) -> DomainsHttpRequest: ...
        def list(
            self, *, customer: str, **kwargs: typing.Any
        ) -> Domains2HttpRequest: ...

    @typing.type_check_only
    class GroupsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AliasesResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, groupKey: str, alias: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def insert(
                self, *, groupKey: str, body: Alias = ..., **kwargs: typing.Any
            ) -> AliasHttpRequest: ...
            def list(
                self, *, groupKey: str, **kwargs: typing.Any
            ) -> AliasesHttpRequest: ...

        def delete(
            self, *, groupKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(self, *, groupKey: str, **kwargs: typing.Any) -> GroupHttpRequest: ...
        def insert(
            self, *, body: Group = ..., **kwargs: typing.Any
        ) -> GroupHttpRequest: ...
        def list(
            self,
            *,
            customer: str = ...,
            domain: str = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal["email"] = ...,
            pageToken: str = ...,
            query: str = ...,
            sortOrder: typing_extensions.Literal["ASCENDING", "DESCENDING"] = ...,
            userKey: str = ...,
            **kwargs: typing.Any
        ) -> GroupsHttpRequest: ...
        def list_next(
            self, previous_request: GroupsHttpRequest, previous_response: Groups
        ) -> GroupsHttpRequest | None: ...
        def patch(
            self, *, groupKey: str, body: Group = ..., **kwargs: typing.Any
        ) -> GroupHttpRequest: ...
        def update(
            self, *, groupKey: str, body: Group = ..., **kwargs: typing.Any
        ) -> GroupHttpRequest: ...
        def aliases(self) -> AliasesResource: ...

    @typing.type_check_only
    class MembersResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, groupKey: str, memberKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, groupKey: str, memberKey: str, **kwargs: typing.Any
        ) -> MemberHttpRequest: ...
        def hasMember(
            self, *, groupKey: str, memberKey: str, **kwargs: typing.Any
        ) -> MembersHasMemberHttpRequest: ...
        def insert(
            self, *, groupKey: str, body: Member = ..., **kwargs: typing.Any
        ) -> MemberHttpRequest: ...
        def list(
            self,
            *,
            groupKey: str,
            includeDerivedMembership: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            roles: str = ...,
            **kwargs: typing.Any
        ) -> MembersHttpRequest: ...
        def list_next(
            self, previous_request: MembersHttpRequest, previous_response: Members
        ) -> MembersHttpRequest | None: ...
        def patch(
            self,
            *,
            groupKey: str,
            memberKey: str,
            body: Member = ...,
            **kwargs: typing.Any
        ) -> MemberHttpRequest: ...
        def update(
            self,
            *,
            groupKey: str,
            memberKey: str,
            body: Member = ...,
            **kwargs: typing.Any
        ) -> MemberHttpRequest: ...

    @typing.type_check_only
    class MobiledevicesResource(googleapiclient.discovery.Resource):
        def action(
            self,
            *,
            customerId: str,
            resourceId: str,
            body: MobileDeviceAction = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def delete(
            self, *, customerId: str, resourceId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            customerId: str,
            resourceId: str,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> MobileDeviceHttpRequest: ...
        def list(
            self,
            *,
            customerId: str,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "deviceId", "email", "lastSync", "model", "name", "os", "status", "type"
            ] = ...,
            pageToken: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            query: str = ...,
            sortOrder: typing_extensions.Literal["ASCENDING", "DESCENDING"] = ...,
            **kwargs: typing.Any
        ) -> MobileDevicesHttpRequest: ...
        def list_next(
            self,
            previous_request: MobileDevicesHttpRequest,
            previous_response: MobileDevices,
        ) -> MobileDevicesHttpRequest | None: ...

    @typing.type_check_only
    class OrgunitsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, customerId: str, orgUnitPath: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customerId: str, orgUnitPath: str, **kwargs: typing.Any
        ) -> OrgUnitHttpRequest: ...
        def insert(
            self, *, customerId: str, body: OrgUnit = ..., **kwargs: typing.Any
        ) -> OrgUnitHttpRequest: ...
        def list(
            self,
            *,
            customerId: str,
            orgUnitPath: str = ...,
            type: typing_extensions.Literal["all", "children"] = ...,
            **kwargs: typing.Any
        ) -> OrgUnitsHttpRequest: ...
        def patch(
            self,
            *,
            customerId: str,
            orgUnitPath: str,
            body: OrgUnit = ...,
            **kwargs: typing.Any
        ) -> OrgUnitHttpRequest: ...
        def update(
            self,
            *,
            customerId: str,
            orgUnitPath: str,
            body: OrgUnit = ...,
            **kwargs: typing.Any
        ) -> OrgUnitHttpRequest: ...

    @typing.type_check_only
    class PrivilegesResource(googleapiclient.discovery.Resource):
        def list(
            self, *, customer: str, **kwargs: typing.Any
        ) -> PrivilegesHttpRequest: ...

    @typing.type_check_only
    class ResourcesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class BuildingsResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, customer: str, buildingId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, customer: str, buildingId: str, **kwargs: typing.Any
            ) -> BuildingHttpRequest: ...
            def insert(
                self,
                *,
                customer: str,
                body: Building = ...,
                coordinatesSource: typing_extensions.Literal[
                    "CLIENT_SPECIFIED", "RESOLVED_FROM_ADDRESS", "SOURCE_UNSPECIFIED"
                ] = ...,
                **kwargs: typing.Any
            ) -> BuildingHttpRequest: ...
            def list(
                self,
                *,
                customer: str,
                maxResults: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> BuildingsHttpRequest: ...
            def list_next(
                self,
                previous_request: BuildingsHttpRequest,
                previous_response: Buildings,
            ) -> BuildingsHttpRequest | None: ...
            def patch(
                self,
                *,
                customer: str,
                buildingId: str,
                body: Building = ...,
                coordinatesSource: typing_extensions.Literal[
                    "CLIENT_SPECIFIED", "RESOLVED_FROM_ADDRESS", "SOURCE_UNSPECIFIED"
                ] = ...,
                **kwargs: typing.Any
            ) -> BuildingHttpRequest: ...
            def update(
                self,
                *,
                customer: str,
                buildingId: str,
                body: Building = ...,
                coordinatesSource: typing_extensions.Literal[
                    "CLIENT_SPECIFIED", "RESOLVED_FROM_ADDRESS", "SOURCE_UNSPECIFIED"
                ] = ...,
                **kwargs: typing.Any
            ) -> BuildingHttpRequest: ...

        @typing.type_check_only
        class CalendarsResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, customer: str, calendarResourceId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, customer: str, calendarResourceId: str, **kwargs: typing.Any
            ) -> CalendarResourceHttpRequest: ...
            def insert(
                self,
                *,
                customer: str,
                body: CalendarResource = ...,
                **kwargs: typing.Any
            ) -> CalendarResourceHttpRequest: ...
            def list(
                self,
                *,
                customer: str,
                maxResults: int = ...,
                orderBy: str = ...,
                pageToken: str = ...,
                query: str = ...,
                **kwargs: typing.Any
            ) -> CalendarResourcesHttpRequest: ...
            def list_next(
                self,
                previous_request: CalendarResourcesHttpRequest,
                previous_response: CalendarResources,
            ) -> CalendarResourcesHttpRequest | None: ...
            def patch(
                self,
                *,
                customer: str,
                calendarResourceId: str,
                body: CalendarResource = ...,
                **kwargs: typing.Any
            ) -> CalendarResourceHttpRequest: ...
            def update(
                self,
                *,
                customer: str,
                calendarResourceId: str,
                body: CalendarResource = ...,
                **kwargs: typing.Any
            ) -> CalendarResourceHttpRequest: ...

        @typing.type_check_only
        class FeaturesResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, customer: str, featureKey: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, customer: str, featureKey: str, **kwargs: typing.Any
            ) -> FeatureHttpRequest: ...
            def insert(
                self, *, customer: str, body: Feature = ..., **kwargs: typing.Any
            ) -> FeatureHttpRequest: ...
            def list(
                self,
                *,
                customer: str,
                maxResults: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> FeaturesHttpRequest: ...
            def list_next(
                self, previous_request: FeaturesHttpRequest, previous_response: Features
            ) -> FeaturesHttpRequest | None: ...
            def patch(
                self,
                *,
                customer: str,
                featureKey: str,
                body: Feature = ...,
                **kwargs: typing.Any
            ) -> FeatureHttpRequest: ...
            def rename(
                self,
                *,
                customer: str,
                oldName: str,
                body: FeatureRename = ...,
                **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def update(
                self,
                *,
                customer: str,
                featureKey: str,
                body: Feature = ...,
                **kwargs: typing.Any
            ) -> FeatureHttpRequest: ...

        def buildings(self) -> BuildingsResource: ...
        def calendars(self) -> CalendarsResource: ...
        def features(self) -> FeaturesResource: ...

    @typing.type_check_only
    class RoleAssignmentsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, customer: str, roleAssignmentId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customer: str, roleAssignmentId: str, **kwargs: typing.Any
        ) -> RoleAssignmentHttpRequest: ...
        def insert(
            self, *, customer: str, body: RoleAssignment = ..., **kwargs: typing.Any
        ) -> RoleAssignmentHttpRequest: ...
        def list(
            self,
            *,
            customer: str,
            maxResults: int = ...,
            pageToken: str = ...,
            roleId: str = ...,
            userKey: str = ...,
            **kwargs: typing.Any
        ) -> RoleAssignmentsHttpRequest: ...
        def list_next(
            self,
            previous_request: RoleAssignmentsHttpRequest,
            previous_response: RoleAssignments,
        ) -> RoleAssignmentsHttpRequest | None: ...

    @typing.type_check_only
    class RolesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, customer: str, roleId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customer: str, roleId: str, **kwargs: typing.Any
        ) -> RoleHttpRequest: ...
        def insert(
            self, *, customer: str, body: Role = ..., **kwargs: typing.Any
        ) -> RoleHttpRequest: ...
        def list(
            self,
            *,
            customer: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> RolesHttpRequest: ...
        def list_next(
            self, previous_request: RolesHttpRequest, previous_response: Roles
        ) -> RolesHttpRequest | None: ...
        def patch(
            self, *, customer: str, roleId: str, body: Role = ..., **kwargs: typing.Any
        ) -> RoleHttpRequest: ...
        def update(
            self, *, customer: str, roleId: str, body: Role = ..., **kwargs: typing.Any
        ) -> RoleHttpRequest: ...

    @typing.type_check_only
    class SchemasResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, customerId: str, schemaKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customerId: str, schemaKey: str, **kwargs: typing.Any
        ) -> SchemaHttpRequest: ...
        def insert(
            self, *, customerId: str, body: Schema = ..., **kwargs: typing.Any
        ) -> SchemaHttpRequest: ...
        def list(
            self, *, customerId: str, **kwargs: typing.Any
        ) -> SchemasHttpRequest: ...
        def patch(
            self,
            *,
            customerId: str,
            schemaKey: str,
            body: Schema = ...,
            **kwargs: typing.Any
        ) -> SchemaHttpRequest: ...
        def update(
            self,
            *,
            customerId: str,
            schemaKey: str,
            body: Schema = ...,
            **kwargs: typing.Any
        ) -> SchemaHttpRequest: ...

    @typing.type_check_only
    class TokensResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, userKey: str, clientId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, userKey: str, clientId: str, **kwargs: typing.Any
        ) -> TokenHttpRequest: ...
        def list(self, *, userKey: str, **kwargs: typing.Any) -> TokensHttpRequest: ...

    @typing.type_check_only
    class TwoStepVerificationResource(googleapiclient.discovery.Resource):
        def turnOff(
            self, *, userKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AliasesResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, userKey: str, alias: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def insert(
                self, *, userKey: str, body: Alias = ..., **kwargs: typing.Any
            ) -> AliasHttpRequest: ...
            def list(
                self,
                *,
                userKey: str,
                event: typing_extensions.Literal["add", "delete"] = ...,
                **kwargs: typing.Any
            ) -> AliasesHttpRequest: ...
            def watch(
                self,
                *,
                userKey: str,
                body: Channel = ...,
                event: typing_extensions.Literal["add", "delete"] = ...,
                **kwargs: typing.Any
            ) -> ChannelHttpRequest: ...

        @typing.type_check_only
        class PhotosResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, userKey: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, userKey: str, **kwargs: typing.Any
            ) -> UserPhotoHttpRequest: ...
            def patch(
                self, *, userKey: str, body: UserPhoto = ..., **kwargs: typing.Any
            ) -> UserPhotoHttpRequest: ...
            def update(
                self, *, userKey: str, body: UserPhoto = ..., **kwargs: typing.Any
            ) -> UserPhotoHttpRequest: ...

        def delete(
            self, *, userKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            userKey: str,
            customFieldMask: str = ...,
            projection: typing_extensions.Literal["basic", "custom", "full"] = ...,
            viewType: typing_extensions.Literal["admin_view", "domain_public"] = ...,
            **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def insert(
            self, *, body: User = ..., **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def list(
            self,
            *,
            customFieldMask: str = ...,
            customer: str = ...,
            domain: str = ...,
            event: typing_extensions.Literal[
                "add", "delete", "makeAdmin", "undelete", "update"
            ] = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "email", "familyName", "givenName"
            ] = ...,
            pageToken: str = ...,
            projection: typing_extensions.Literal["basic", "custom", "full"] = ...,
            query: str = ...,
            showDeleted: str = ...,
            sortOrder: typing_extensions.Literal["ASCENDING", "DESCENDING"] = ...,
            viewType: typing_extensions.Literal["admin_view", "domain_public"] = ...,
            **kwargs: typing.Any
        ) -> UsersHttpRequest: ...
        def list_next(
            self, previous_request: UsersHttpRequest, previous_response: Users
        ) -> UsersHttpRequest | None: ...
        def makeAdmin(
            self, *, userKey: str, body: UserMakeAdmin = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def patch(
            self, *, userKey: str, body: User = ..., **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def signOut(
            self, *, userKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def undelete(
            self, *, userKey: str, body: UserUndelete = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def update(
            self, *, userKey: str, body: User = ..., **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def watch(
            self,
            *,
            body: Channel = ...,
            customFieldMask: str = ...,
            customer: str = ...,
            domain: str = ...,
            event: typing_extensions.Literal[
                "add", "delete", "makeAdmin", "undelete", "update"
            ] = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "email", "familyName", "givenName"
            ] = ...,
            pageToken: str = ...,
            projection: typing_extensions.Literal["basic", "custom", "full"] = ...,
            query: str = ...,
            showDeleted: str = ...,
            sortOrder: typing_extensions.Literal["ASCENDING", "DESCENDING"] = ...,
            viewType: typing_extensions.Literal["admin_view", "domain_public"] = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...
        def aliases(self) -> AliasesResource: ...
        def photos(self) -> PhotosResource: ...

    @typing.type_check_only
    class VerificationCodesResource(googleapiclient.discovery.Resource):
        def generate(
            self, *, userKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def invalidate(
            self, *, userKey: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def list(
            self, *, userKey: str, **kwargs: typing.Any
        ) -> VerificationCodesHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def asps(self) -> AspsResource: ...
    def channels(self) -> ChannelsResource: ...
    def chromeosdevices(self) -> ChromeosdevicesResource: ...
    def customer(self) -> CustomerResource: ...
    def customers(self) -> CustomersResource: ...
    def domainAliases(self) -> DomainAliasesResource: ...
    def domains(self) -> DomainsResource: ...
    def groups(self) -> GroupsResource: ...
    def members(self) -> MembersResource: ...
    def mobiledevices(self) -> MobiledevicesResource: ...
    def orgunits(self) -> OrgunitsResource: ...
    def privileges(self) -> PrivilegesResource: ...
    def resources(self) -> ResourcesResource: ...
    def roleAssignments(self) -> RoleAssignmentsResource: ...
    def roles(self) -> RolesResource: ...
    def schemas(self) -> SchemasResource: ...
    def tokens(self) -> TokensResource: ...
    def twoStepVerification(self) -> TwoStepVerificationResource: ...
    def users(self) -> UsersResource: ...
    def verificationCodes(self) -> VerificationCodesResource: ...

@typing.type_check_only
class AliasHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Alias: ...

@typing.type_check_only
class AliasesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Aliases: ...

@typing.type_check_only
class AspHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Asp: ...

@typing.type_check_only
class AspsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Asps: ...

@typing.type_check_only
class BatchCreatePrintServersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchCreatePrintServersResponse: ...

@typing.type_check_only
class BatchCreatePrintersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchCreatePrintersResponse: ...

@typing.type_check_only
class BatchDeletePrintServersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchDeletePrintServersResponse: ...

@typing.type_check_only
class BatchDeletePrintersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchDeletePrintersResponse: ...

@typing.type_check_only
class BuildingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Building: ...

@typing.type_check_only
class BuildingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Buildings: ...

@typing.type_check_only
class CalendarResourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CalendarResource: ...

@typing.type_check_only
class CalendarResourcesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CalendarResources: ...

@typing.type_check_only
class ChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Channel: ...

@typing.type_check_only
class ChromeOsDeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ChromeOsDevice: ...

@typing.type_check_only
class ChromeOsDevicesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ChromeOsDevices: ...

@typing.type_check_only
class CustomerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Customer: ...

@typing.type_check_only
class DirectoryChromeosdevicesCommandHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DirectoryChromeosdevicesCommand: ...

@typing.type_check_only
class DirectoryChromeosdevicesIssueCommandResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DirectoryChromeosdevicesIssueCommandResponse: ...

@typing.type_check_only
class DomainAliasHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DomainAlias: ...

@typing.type_check_only
class DomainAliasesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DomainAliases: ...

@typing.type_check_only
class DomainsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Domains: ...

@typing.type_check_only
class Domains2HttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Domains2: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FeatureHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Feature: ...

@typing.type_check_only
class FeaturesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Features: ...

@typing.type_check_only
class GroupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Group: ...

@typing.type_check_only
class GroupsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Groups: ...

@typing.type_check_only
class ListPrintServersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPrintServersResponse: ...

@typing.type_check_only
class ListPrinterModelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPrinterModelsResponse: ...

@typing.type_check_only
class ListPrintersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPrintersResponse: ...

@typing.type_check_only
class MemberHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Member: ...

@typing.type_check_only
class MembersHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Members: ...

@typing.type_check_only
class MembersHasMemberHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MembersHasMember: ...

@typing.type_check_only
class MobileDeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MobileDevice: ...

@typing.type_check_only
class MobileDevicesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MobileDevices: ...

@typing.type_check_only
class OrgUnitHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrgUnit: ...

@typing.type_check_only
class OrgUnitsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrgUnits: ...

@typing.type_check_only
class PrintServerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PrintServer: ...

@typing.type_check_only
class PrinterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Printer: ...

@typing.type_check_only
class PrivilegesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Privileges: ...

@typing.type_check_only
class RoleHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Role: ...

@typing.type_check_only
class RoleAssignmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RoleAssignment: ...

@typing.type_check_only
class RoleAssignmentsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RoleAssignments: ...

@typing.type_check_only
class RolesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Roles: ...

@typing.type_check_only
class SchemaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Schema: ...

@typing.type_check_only
class SchemasHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Schemas: ...

@typing.type_check_only
class TokenHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Token: ...

@typing.type_check_only
class TokensHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Tokens: ...

@typing.type_check_only
class UserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> User: ...

@typing.type_check_only
class UserPhotoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UserPhoto: ...

@typing.type_check_only
class UsersHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Users: ...

@typing.type_check_only
class VerificationCodesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> VerificationCodes: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AdExchangeBuyerIIResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ClientsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class InvitationsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    accountId: str,
                    clientAccountId: str,
                    body: ClientUserInvitation = ...,
                    **kwargs: typing.Any
                ) -> ClientUserInvitationHttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    clientAccountId: str,
                    invitationId: str,
                    **kwargs: typing.Any
                ) -> ClientUserInvitationHttpRequest: ...
                def list(
                    self,
                    *,
                    accountId: str,
                    clientAccountId: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListClientUserInvitationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListClientUserInvitationsResponseHttpRequest,
                    previous_response: ListClientUserInvitationsResponse,
                ) -> ListClientUserInvitationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class UsersResource(googleapiclient.discovery.Resource):
                def get(
                    self,
                    *,
                    accountId: str,
                    clientAccountId: str,
                    userId: str,
                    **kwargs: typing.Any
                ) -> ClientUserHttpRequest: ...
                def list(
                    self,
                    *,
                    accountId: str,
                    clientAccountId: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListClientUsersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListClientUsersResponseHttpRequest,
                    previous_response: ListClientUsersResponse,
                ) -> ListClientUsersResponseHttpRequest | None: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    clientAccountId: str,
                    userId: str,
                    body: ClientUser = ...,
                    **kwargs: typing.Any
                ) -> ClientUserHttpRequest: ...

            def create(
                self, *, accountId: str, body: Client = ..., **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def get(
                self, *, accountId: str, clientAccountId: str, **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                partnerClientId: str = ...,
                **kwargs: typing.Any
            ) -> ListClientsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListClientsResponseHttpRequest,
                previous_response: ListClientsResponse,
            ) -> ListClientsResponseHttpRequest | None: ...
            def update(
                self,
                *,
                accountId: str,
                clientAccountId: str,
                body: Client = ...,
                **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def invitations(self) -> InvitationsResource: ...
            def users(self) -> UsersResource: ...

        @typing.type_check_only
        class CreativesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DealAssociationsResource(googleapiclient.discovery.Resource):
                def add(
                    self,
                    *,
                    accountId: str,
                    creativeId: str,
                    body: AddDealAssociationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def list(
                    self,
                    *,
                    accountId: str,
                    creativeId: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    query: str = ...,
                    **kwargs: typing.Any
                ) -> ListDealAssociationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListDealAssociationsResponseHttpRequest,
                    previous_response: ListDealAssociationsResponse,
                ) -> ListDealAssociationsResponseHttpRequest | None: ...
                def remove(
                    self,
                    *,
                    accountId: str,
                    creativeId: str,
                    body: RemoveDealAssociationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...

            def create(
                self,
                *,
                accountId: str,
                body: Creative = ...,
                duplicateIdMode: typing_extensions.Literal[
                    "NO_DUPLICATES", "FORCE_ENABLE_DUPLICATE_IDS"
                ] = ...,
                **kwargs: typing.Any
            ) -> CreativeHttpRequest: ...
            def get(
                self, *, accountId: str, creativeId: str, **kwargs: typing.Any
            ) -> CreativeHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                query: str = ...,
                **kwargs: typing.Any
            ) -> ListCreativesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListCreativesResponseHttpRequest,
                previous_response: ListCreativesResponse,
            ) -> ListCreativesResponseHttpRequest | None: ...
            def stopWatching(
                self,
                *,
                accountId: str,
                creativeId: str,
                body: StopWatchingCreativeRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def update(
                self,
                *,
                accountId: str,
                creativeId: str,
                body: Creative = ...,
                **kwargs: typing.Any
            ) -> CreativeHttpRequest: ...
            def watch(
                self,
                *,
                accountId: str,
                creativeId: str,
                body: WatchCreativeRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def dealAssociations(self) -> DealAssociationsResource: ...

        @typing.type_check_only
        class FinalizedProposalsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                accountId: str,
                filter: str = ...,
                filterSyntax: typing_extensions.Literal[
                    "FILTER_SYNTAX_UNSPECIFIED", "PQL", "LIST_FILTER"
                ] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListProposalsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListProposalsResponseHttpRequest,
                previous_response: ListProposalsResponse,
            ) -> ListProposalsResponseHttpRequest | None: ...
            def pause(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: PauseProposalDealsRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def resume(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: ResumeProposalDealsRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...

        @typing.type_check_only
        class ProductsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, accountId: str, productId: str, **kwargs: typing.Any
            ) -> ProductHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListProductsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListProductsResponseHttpRequest,
                previous_response: ListProductsResponse,
            ) -> ListProductsResponseHttpRequest | None: ...

        @typing.type_check_only
        class ProposalsResource(googleapiclient.discovery.Resource):
            def accept(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: AcceptProposalRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def addNote(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: AddNoteRequest = ...,
                **kwargs: typing.Any
            ) -> NoteHttpRequest: ...
            def cancelNegotiation(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: CancelNegotiationRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def completeSetup(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: CompleteSetupRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def create(
                self, *, accountId: str, body: Proposal = ..., **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def get(
                self, *, accountId: str, proposalId: str, **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                filter: str = ...,
                filterSyntax: typing_extensions.Literal[
                    "FILTER_SYNTAX_UNSPECIFIED", "PQL", "LIST_FILTER"
                ] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListProposalsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListProposalsResponseHttpRequest,
                previous_response: ListProposalsResponse,
            ) -> ListProposalsResponseHttpRequest | None: ...
            def pause(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: PauseProposalRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def resume(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: ResumeProposalRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def update(
                self,
                *,
                accountId: str,
                proposalId: str,
                body: Proposal = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...

        @typing.type_check_only
        class PublisherProfilesResource(googleapiclient.discovery.Resource):
            def get(
                self, *, accountId: str, publisherProfileId: str, **kwargs: typing.Any
            ) -> PublisherProfileHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListPublisherProfilesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListPublisherProfilesResponseHttpRequest,
                previous_response: ListPublisherProfilesResponse,
            ) -> ListPublisherProfilesResponseHttpRequest | None: ...

        def clients(self) -> ClientsResource: ...
        def creatives(self) -> CreativesResource: ...
        def finalizedProposals(self) -> FinalizedProposalsResource: ...
        def products(self) -> ProductsResource: ...
        def proposals(self) -> ProposalsResource: ...
        def publisherProfiles(self) -> PublisherProfilesResource: ...

    @typing.type_check_only
    class BiddersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AccountsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class FilterSetsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class BidMetricsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListBidMetricsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListBidMetricsResponseHttpRequest,
                        previous_response: ListBidMetricsResponse,
                    ) -> ListBidMetricsResponseHttpRequest | None: ...

                @typing.type_check_only
                class BidResponseErrorsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListBidResponseErrorsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListBidResponseErrorsResponseHttpRequest,
                        previous_response: ListBidResponseErrorsResponse,
                    ) -> ListBidResponseErrorsResponseHttpRequest | None: ...

                @typing.type_check_only
                class BidResponsesWithoutBidsResource(
                    googleapiclient.discovery.Resource
                ):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListBidResponsesWithoutBidsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListBidResponsesWithoutBidsResponseHttpRequest,
                        previous_response: ListBidResponsesWithoutBidsResponse,
                    ) -> ListBidResponsesWithoutBidsResponseHttpRequest | None: ...

                @typing.type_check_only
                class FilteredBidRequestsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListFilteredBidRequestsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListFilteredBidRequestsResponseHttpRequest,
                        previous_response: ListFilteredBidRequestsResponse,
                    ) -> ListFilteredBidRequestsResponseHttpRequest | None: ...

                @typing.type_check_only
                class FilteredBidsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class CreativesResource(googleapiclient.discovery.Resource):
                        def list(
                            self,
                            *,
                            filterSetName: str,
                            creativeStatusId: int,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListCreativeStatusBreakdownByCreativeResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListCreativeStatusBreakdownByCreativeResponseHttpRequest,
                            previous_response: ListCreativeStatusBreakdownByCreativeResponse,
                        ) -> ListCreativeStatusBreakdownByCreativeResponseHttpRequest | None: ...

                    @typing.type_check_only
                    class DetailsResource(googleapiclient.discovery.Resource):
                        def list(
                            self,
                            *,
                            filterSetName: str,
                            creativeStatusId: int,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListCreativeStatusBreakdownByDetailResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListCreativeStatusBreakdownByDetailResponseHttpRequest,
                            previous_response: ListCreativeStatusBreakdownByDetailResponse,
                        ) -> ListCreativeStatusBreakdownByDetailResponseHttpRequest | None: ...

                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListFilteredBidsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListFilteredBidsResponseHttpRequest,
                        previous_response: ListFilteredBidsResponse,
                    ) -> ListFilteredBidsResponseHttpRequest | None: ...
                    def creatives(self) -> CreativesResource: ...
                    def details(self) -> DetailsResource: ...

                @typing.type_check_only
                class ImpressionMetricsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListImpressionMetricsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListImpressionMetricsResponseHttpRequest,
                        previous_response: ListImpressionMetricsResponse,
                    ) -> ListImpressionMetricsResponseHttpRequest | None: ...

                @typing.type_check_only
                class LosingBidsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListLosingBidsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListLosingBidsResponseHttpRequest,
                        previous_response: ListLosingBidsResponse,
                    ) -> ListLosingBidsResponseHttpRequest | None: ...

                @typing.type_check_only
                class NonBillableWinningBidsResource(
                    googleapiclient.discovery.Resource
                ):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListNonBillableWinningBidsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListNonBillableWinningBidsResponseHttpRequest,
                        previous_response: ListNonBillableWinningBidsResponse,
                    ) -> ListNonBillableWinningBidsResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    ownerName: str,
                    body: FilterSet = ...,
                    isTransient: bool = ...,
                    **kwargs: typing.Any
                ) -> FilterSetHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> FilterSetHttpRequest: ...
                def list(
                    self,
                    *,
                    ownerName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListFilterSetsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListFilterSetsResponseHttpRequest,
                    previous_response: ListFilterSetsResponse,
                ) -> ListFilterSetsResponseHttpRequest | None: ...
                def bidMetrics(self) -> BidMetricsResource: ...
                def bidResponseErrors(self) -> BidResponseErrorsResource: ...
                def bidResponsesWithoutBids(
                    self,
                ) -> BidResponsesWithoutBidsResource: ...
                def filteredBidRequests(self) -> FilteredBidRequestsResource: ...
                def filteredBids(self) -> FilteredBidsResource: ...
                def impressionMetrics(self) -> ImpressionMetricsResource: ...
                def losingBids(self) -> LosingBidsResource: ...
                def nonBillableWinningBids(self) -> NonBillableWinningBidsResource: ...

            def filterSets(self) -> FilterSetsResource: ...

        @typing.type_check_only
        class FilterSetsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class BidMetricsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListBidMetricsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListBidMetricsResponseHttpRequest,
                    previous_response: ListBidMetricsResponse,
                ) -> ListBidMetricsResponseHttpRequest | None: ...

            @typing.type_check_only
            class BidResponseErrorsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListBidResponseErrorsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListBidResponseErrorsResponseHttpRequest,
                    previous_response: ListBidResponseErrorsResponse,
                ) -> ListBidResponseErrorsResponseHttpRequest | None: ...

            @typing.type_check_only
            class BidResponsesWithoutBidsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListBidResponsesWithoutBidsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListBidResponsesWithoutBidsResponseHttpRequest,
                    previous_response: ListBidResponsesWithoutBidsResponse,
                ) -> ListBidResponsesWithoutBidsResponseHttpRequest | None: ...

            @typing.type_check_only
            class FilteredBidRequestsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListFilteredBidRequestsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListFilteredBidRequestsResponseHttpRequest,
                    previous_response: ListFilteredBidRequestsResponse,
                ) -> ListFilteredBidRequestsResponseHttpRequest | None: ...

            @typing.type_check_only
            class FilteredBidsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class CreativesResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        creativeStatusId: int,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListCreativeStatusBreakdownByCreativeResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListCreativeStatusBreakdownByCreativeResponseHttpRequest,
                        previous_response: ListCreativeStatusBreakdownByCreativeResponse,
                    ) -> ListCreativeStatusBreakdownByCreativeResponseHttpRequest | None: ...

                @typing.type_check_only
                class DetailsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        filterSetName: str,
                        creativeStatusId: int,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListCreativeStatusBreakdownByDetailResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListCreativeStatusBreakdownByDetailResponseHttpRequest,
                        previous_response: ListCreativeStatusBreakdownByDetailResponse,
                    ) -> ListCreativeStatusBreakdownByDetailResponseHttpRequest | None: ...

                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListFilteredBidsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListFilteredBidsResponseHttpRequest,
                    previous_response: ListFilteredBidsResponse,
                ) -> ListFilteredBidsResponseHttpRequest | None: ...
                def creatives(self) -> CreativesResource: ...
                def details(self) -> DetailsResource: ...

            @typing.type_check_only
            class ImpressionMetricsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListImpressionMetricsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListImpressionMetricsResponseHttpRequest,
                    previous_response: ListImpressionMetricsResponse,
                ) -> ListImpressionMetricsResponseHttpRequest | None: ...

            @typing.type_check_only
            class LosingBidsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListLosingBidsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListLosingBidsResponseHttpRequest,
                    previous_response: ListLosingBidsResponse,
                ) -> ListLosingBidsResponseHttpRequest | None: ...

            @typing.type_check_only
            class NonBillableWinningBidsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    filterSetName: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListNonBillableWinningBidsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListNonBillableWinningBidsResponseHttpRequest,
                    previous_response: ListNonBillableWinningBidsResponse,
                ) -> ListNonBillableWinningBidsResponseHttpRequest | None: ...

            def create(
                self,
                *,
                ownerName: str,
                body: FilterSet = ...,
                isTransient: bool = ...,
                **kwargs: typing.Any
            ) -> FilterSetHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> FilterSetHttpRequest: ...
            def list(
                self,
                *,
                ownerName: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListFilterSetsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListFilterSetsResponseHttpRequest,
                previous_response: ListFilterSetsResponse,
            ) -> ListFilterSetsResponseHttpRequest | None: ...
            def bidMetrics(self) -> BidMetricsResource: ...
            def bidResponseErrors(self) -> BidResponseErrorsResource: ...
            def bidResponsesWithoutBids(self) -> BidResponsesWithoutBidsResource: ...
            def filteredBidRequests(self) -> FilteredBidRequestsResource: ...
            def filteredBids(self) -> FilteredBidsResource: ...
            def impressionMetrics(self) -> ImpressionMetricsResource: ...
            def losingBids(self) -> LosingBidsResource: ...
            def nonBillableWinningBids(self) -> NonBillableWinningBidsResource: ...

        def accounts(self) -> AccountsResource: ...
        def filterSets(self) -> FilterSetsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def bidders(self) -> BiddersResource: ...

@typing.type_check_only
class ClientHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Client: ...

@typing.type_check_only
class ClientUserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClientUser: ...

@typing.type_check_only
class ClientUserInvitationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClientUserInvitation: ...

@typing.type_check_only
class CreativeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Creative: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FilterSetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FilterSet: ...

@typing.type_check_only
class ListBidMetricsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBidMetricsResponse: ...

@typing.type_check_only
class ListBidResponseErrorsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBidResponseErrorsResponse: ...

@typing.type_check_only
class ListBidResponsesWithoutBidsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBidResponsesWithoutBidsResponse: ...

@typing.type_check_only
class ListClientUserInvitationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientUserInvitationsResponse: ...

@typing.type_check_only
class ListClientUsersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientUsersResponse: ...

@typing.type_check_only
class ListClientsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientsResponse: ...

@typing.type_check_only
class ListCreativeStatusBreakdownByCreativeResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCreativeStatusBreakdownByCreativeResponse: ...

@typing.type_check_only
class ListCreativeStatusBreakdownByDetailResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCreativeStatusBreakdownByDetailResponse: ...

@typing.type_check_only
class ListCreativesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCreativesResponse: ...

@typing.type_check_only
class ListDealAssociationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDealAssociationsResponse: ...

@typing.type_check_only
class ListFilterSetsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFilterSetsResponse: ...

@typing.type_check_only
class ListFilteredBidRequestsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFilteredBidRequestsResponse: ...

@typing.type_check_only
class ListFilteredBidsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFilteredBidsResponse: ...

@typing.type_check_only
class ListImpressionMetricsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListImpressionMetricsResponse: ...

@typing.type_check_only
class ListLosingBidsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLosingBidsResponse: ...

@typing.type_check_only
class ListNonBillableWinningBidsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListNonBillableWinningBidsResponse: ...

@typing.type_check_only
class ListProductsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProductsResponse: ...

@typing.type_check_only
class ListProposalsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProposalsResponse: ...

@typing.type_check_only
class ListPublisherProfilesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPublisherProfilesResponse: ...

@typing.type_check_only
class NoteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Note: ...

@typing.type_check_only
class ProductHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Product: ...

@typing.type_check_only
class ProposalHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Proposal: ...

@typing.type_check_only
class PublisherProfileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PublisherProfile: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class MyBusinessPlaceActionsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class PlaceActionLinksResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: PlaceActionLink = ..., **kwargs: typing.Any
            ) -> PlaceActionLinkHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> PlaceActionLinkHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListPlaceActionLinksResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListPlaceActionLinksResponseHttpRequest,
                previous_response: ListPlaceActionLinksResponse,
            ) -> ListPlaceActionLinksResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: PlaceActionLink = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> PlaceActionLinkHttpRequest: ...

        def placeActionLinks(self) -> PlaceActionLinksResource: ...

    @typing.type_check_only
    class PlaceActionTypeMetadataResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            filter: str = ...,
            languageCode: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListPlaceActionTypeMetadataResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListPlaceActionTypeMetadataResponseHttpRequest,
            previous_response: ListPlaceActionTypeMetadataResponse,
        ) -> ListPlaceActionTypeMetadataResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def locations(self) -> LocationsResource: ...
    def placeActionTypeMetadata(self) -> PlaceActionTypeMetadataResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListPlaceActionLinksResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPlaceActionLinksResponse: ...

@typing.type_check_only
class ListPlaceActionTypeMetadataResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPlaceActionTypeMetadataResponse: ...

@typing.type_check_only
class PlaceActionLinkHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlaceActionLink: ...
